@@ -9,6 +9,8 @@ fn main() {
     // preedit: UpdatePreeditTextSignal { text: "ム", cursor_pos: 1, visible: true }
     // commit: CommitTextSignal { text: "ム" }
 
+    simple_logger::SimpleLogger::new().init().unwrap();
+
     let bus = Bus::new().unwrap();
     let ctx = bus.create_input_context("input ctx lel").unwrap();
     ctx.set_capabilities(Capabilites::PREEDIT_TEXT | Capabilites::FOCUS);
@@ -24,6 +26,8 @@ fn main() {
     })
     .unwrap();
 
+    ctx.focus_in().unwrap();
+
     // The `M` key
     ctx.process_key_event(109, 50, Modifiers::empty()).unwrap();
     // The `U` key
@@ -32,6 +36,8 @@ fn main() {
     ctx.process_key_event(65293, 28, Modifiers::empty())
         .unwrap();
 
+    ctx.focus_out().unwrap();
+
     loop {
         match bus.process(std::time::Duration::from_secs(0)) {
             Ok(true) => {}
